# Module

[Sigstickers Index](../README.md#sigstickers-index) / [Sigstickers](./index.md#sigstickers) / Module

> Auto-generated documentation for [sigstickers.__main__](../../../sigstickers/__main__.py) module.
- [Module](#module)
